/*
 * Copyright 2013 Red Hat Inc. and/or its affiliates and other contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.switchyard.common.property;

import java.security.AccessController;
import java.security.PrivilegedAction;

/**
 * Resolves properties from System Properties and the System environment.
 *
 * @author David Ward &lt;<a href="mailto:dward@jboss.org">dward@jboss.org</a>&gt; &copy; 2012 Red Hat Inc.
 */
public final class SystemPropertyResolver implements PropertyResolver {

    /** The singleton instance. */
    public static final SystemPropertyResolver INSTANCE = new SystemPropertyResolver();

    /** The singleton constructor. */
    private SystemPropertyResolver() {}

    /**
     * {@inheritDoc}
     */
    @Override
    public final Object resolveProperty(final String key) {
        return key != null ? AccessController.doPrivileged(new PrivilegedAction<String>() {
           public String run() {
               String value = System.getProperty(key);
               if (value == null && key.startsWith("env.")) {
                   value =  System.getenv(key.substring(4));
               }
               return value;
           }
        }) : null;
    }
}
